Mirror of the gdb-patches mailing list
 help / color / mirror / Atom feed
From: Stephan Springl <springl-gdb@bfw-online.de>
To: gdb-patches@sourceware.org
Subject: [PATCH] Topo in gdb comment
Date: Thu, 25 Sep 2008 11:24:00 -0000	[thread overview]
Message-ID: <Pine.LNX.4.64.0809251320080.4897@lar.bfw.de> (raw)

Hi,

while browsing the gdb sources, I found the following as of cvs two hours 
ago.

Thank you for your work.
Regards,
Stephan

commit 79662b1ee004e54352560f67c0781a737352c6e6
Author: Stephan Springl <springl-gdb@bfw-online.de>
Date:   Thu Sep 25 11:49:30 2008 +0200

     fix comment typos

diff --git a/src/gdb/stack.c b/src/gdb/stack.c
index 1725dc6..2efe3e5 100644
--- a/src/gdb/stack.c
+++ b/src/gdb/stack.c
@@ -202,9 +202,9 @@ print_this_frame_argument_p (struct symbol *sym)
     of arguments according to the stack frame (or -1 if the number of
     arguments is unknown).  */

 /* Note that currently the "number of argumentss according to the
     stack frame" is only known on VAX where i refers to the "number of
-   ints of argumentss according to the stack frame".  */
+   ints of arguments according to the stack frame".  */

  static void
  print_frame_args (struct symbol *func, struct frame_info *frame,
@@ -202,9 +202,9 @@ print_this_frame_argument_p (struct symbol *sym)
     arguments is unknown).  */

-/* Note that currently the "number of argumentss according to the
+/* Note that currently the "number of arguments according to the
     stack frame" is only known on VAX where i refers to the "number of


-- 
Stephan Springl              springl-gdb@bfw-online.de


             reply	other threads:[~2008-09-25 11:24 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2008-09-25 11:24 Stephan Springl [this message]
2008-09-25 16:08 ` Joel Brobecker

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=Pine.LNX.4.64.0809251320080.4897@lar.bfw.de \
    --to=springl-gdb@bfw-online.de \
    --cc=gdb-patches@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox